# Citing foodspec

If you use foodspec in your research, we kindly ask you to cite:

1. The **foodspec software** (this package).  
2. The **MethodsX protocol article** that formally describes the workflow
   (once it is published).

## Software citation

Citation metadata for the foodspec software is provided in the `CITATION.cff`
file at the root of the repository. Many reference managers and tools can
import this file directly.

A provisional human-readable citation is:

> Chandrasekar Subramani Narayan, *foodspec: A Python toolkit for Raman and
> FTIR spectroscopy in food science*, software version 0.2.0, 2025.

Please update this with the exact release details that you are using.

## MethodsX protocol article

Once the MethodsX article describing the computational protocol is accepted,
this page will be updated with the formal citation (authors, title, journal,
volume, pages, DOI).

Until then, you can refer to the software citation and describe the method as
“the foodspec protocol for Raman/FTIR analysis in food science”.
